"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .entailment_pb2 import *
class EntailmentServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def Entailment(self,
        request: global___EntailmentRequest,
    ) -> global___EntailmentResponse: ...


class EntailmentServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Entailment(self,
        request: global___EntailmentRequest,
        context: grpc.ServicerContext,
    ) -> global___EntailmentResponse: ...


def add_EntailmentServiceServicer_to_server(servicer: EntailmentServiceServicer, server: grpc.Server) -> None: ...
