"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .nlp_pb2 import *
class NlpServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def DocBin(self,
        request: global___DocBinRequest,
    ) -> global___DocBinResponse: ...

    def Vector(self,
        request: global___VectorRequest,
    ) -> global___VectorResponse: ...


class NlpServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def DocBin(self,
        request: global___DocBinRequest,
        context: grpc.ServicerContext,
    ) -> global___DocBinResponse: ...

    @abc.abstractmethod
    def Vector(self,
        request: global___VectorRequest,
        context: grpc.ServicerContext,
    ) -> global___VectorResponse: ...


def add_NlpServiceServicer_to_server(servicer: NlpServiceServicer, server: grpc.Server) -> None: ...
