"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

global___Language = Language
class _Language(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Language.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    LANGUAGE_UNSPECIFIED = Language.V(0)
    LANGUAGE_EN = Language.V(1)
    LANGUAGE_DE = Language.V(2)
class Language(metaclass=_Language):
    V = typing.NewType('V', builtins.int)
LANGUAGE_UNSPECIFIED = Language.V(0)
LANGUAGE_EN = Language.V(1)
LANGUAGE_DE = Language.V(2)
